package com.kernelmaft.zanbur.ui

import androidx.compose.foundation.layout.*
import androidx.compose.foundation.layout.Arrangement.Center
import androidx.compose.material3.*
import androidx.compose.material3.ButtonDefaults.buttonColors
import androidx.compose.material3.ButtonDefaults.filledTonalButtonColors
import androidx.compose.material3.ButtonDefaults.shape
import androidx.compose.runtime.*
import androidx.compose.ui.*
import androidx.compose.ui.Alignment.Companion.CenterHorizontally
import com.kernelmaft.zanbur.common.*



@Composable fun AppFrame ( content : @Composable () -> Unit ) {
	ZanburTheme {
		Scaffold { scaffoldPadding ->
			CenteringColumn ( Modifier . padding (scaffoldPadding) . fillMaxSize () ) {
				content ()
			}
		}
	}
}

@Composable fun SceneSwitcher ( group : Group , onSwitch : (Scene) -> Unit ) {
	CenteringColumn {
		Text ( group . name )
		Spacer ( Modifier . height ( compactSpacing ) )

		for ( scene in group . scenes ) {
			val colors =
				if ( scene . id == group . currentScene ?. id ) buttonColors ()
				else filledTonalButtonColors ()

			Button ( { onSwitch (scene) } , Modifier . fillMaxWidth () , true , shape , colors ) {
				Text ( scene . name )
			}
		}
	}
}

@Composable fun CenteringColumn (
	modifier : Modifier = Modifier ,
	content : @Composable ColumnScope . () -> Unit ,
) = Column ( modifier , Center , CenterHorizontally , content )
